@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
 Constants for the calculation of water steam properties
@@ -34,3 +35,9 @@ __CRITICAL_DENSITY_D20_1992__ = 356  # +-5 kg m^-1
 # Other common constants used in calculations
 __ABSOLUTE_ZERO_CELSIUS__ = -273.15  # °C
 __ABSOLUTE_ZERO_FAHRENHEIT__ = -459.67  # °F
+
+
+# IAPWS R15-11
+__SPECIFIC_GAS_CONSTANT_IAPWS_R15_11__ = 0.46151805 # kJ kg^-1 K^-1
+__CRITICAL_TEMPERATURE_IAPWS_R15_11__ = 647.096  # K
+__CRITICAL_DENSITY_IAPWS_R15_11__ = 322.0  # kg m^-1
