@@ -1,3 +1,4 @@
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import math
 import logging
@@ -6,7 +7,8 @@ from .Regions import Region1, Region2, Region3, Region4, Region5
 from . import TransportProperties
 from . import Constants
 from .UnitConverter import UnitConverter
-
+from . import IAPWS_R14
+from . import IAPWS_R15
 
 class XSteam(object):
     """Main pyXSteam object. Abstract of all other functions to allow auto selection of
@@ -22,10 +24,16 @@ class XSteam(object):
     UNIT_SYSTEM_MKS = UnitConverter.__UNIT_SYSTEM_MKS__
     UNIT_SYSTEM_FLS = UnitConverter.__UNIT_SYSTEM_FLS__
 
+    TYPE_ICE_Ih = IAPWS_R14.__TYPE_ICE_Ih__
+    TYPE_ICE_III = IAPWS_R14.__TYPE_ICE_III__
+    TYPE_ICE_V = IAPWS_R14.__TYPE_ICE_V__
+    TYPE_ICE_VI = IAPWS_R14.__TYPE_ICE_VI__
+    TYPE_ICE_VII = IAPWS_R14.__TYPE_ICE_VII__
+
     def __init__(self, unitSystem=UnitConverter.__UNIT_SYSTEM_BARE__):
         self.logger = logging.getLogger(__name__)
         self.unitConverter = UnitConverter(unitSystem)
-        self.logger.info('initialised pyXSteam with Unit System %s', self.unitConverter)
+        self.logger.info('initialised pyXSteam with Unit System "{}"'.format(self.unitConverter))
 
     def specificGasConstant(self):
         """returns the specific Gas Constant R in kJ kg^-1 K^-1"""
@@ -1785,16 +1793,18 @@ class XSteam(object):
         rho = 1 / v
         return self.unitConverter.fromSIunit_tc(TransportProperties.tc_ptrho(p, T, rho))
 
-    def tc_pt(self, p, t):
+    def tc_pt(self, p, t, mode=None):
         """Thermal conductivity as a function of pressure and temperature
 
         Args:
             p (float): preasure value
             t (float): temperature value
+            mode (optional): swith to using formular from R15
 
         Returns:
             tc (float): thermal conductivity
         """
+
         Ts = t
         ps = p
         v = self.v_pt(ps, Ts)
@@ -1802,7 +1812,15 @@ class XSteam(object):
         T = self.unitConverter.toSIunit_T(Ts)
         v = self.unitConverter.toSIunit_v(v)
         rho = 1 / v
-        return self.unitConverter.fromSIunit_tc(TransportProperties.tc_ptrho(p, T, rho))
+
+        if mode is None:
+            tc = self.unitConverter.fromSIunit_tc(TransportProperties.tc_ptrho(p, T, rho))
+        else:
+            cp = self.Cp_pt(p, t)
+            cv = self.Cv_pt(p, t)
+            my = self.my_pt(p, t)
+            tc = self.unitConverter.fromSIunit_tc(IAPWS_R15.tc_ptrhocp_R15(p, T, rho, my, cp, cv))
+        return tc
 
     def tc_ph(self, p, h):
         """Thermal conductivity as a function of pressure and enthalpy
@@ -1934,3 +1952,102 @@ class XSteam(object):
         else:
             self.logger.warning('pressure out of range')
             return float("NaN")
+
+# ***********************************************************************************************************
+# Revised Release on the Pressure along the Melting and Sublimation Curves of Ordinary Water Substance
+# Release IAPWS R14-08(2011)
+# http://www.iapws.org/relguide/MeltSub2011.pdf
+    def pmelt_t(self, t, hint=None):
+        """Pressure along the melting curve as a function of temperature. Based on IAPWS R14-08(2011)
+        http://www.iapws.org/relguide/MeltSub2011.pdf
+        Because of the shape of the meltin curve it is not possible to automaticaly select the correct region
+        automaticaly. Therfore the optional hint-parameter is used to tell the function which area you are interested in.
+        The hint-values are namend after the ice types.
+        XSteam.TYPE_ICE_Ih = 1
+        XSteam.TYPE_ICE_III = 3
+        XSteam.TYPE_ICE_V = 5
+        XSteam.TYPE_ICE_VI = 6
+        XSteam.TYPE_ICE_VII = 7
+        If the hint is not one of the values above or None(Default), an Exception is raised
+
+        Args:
+            t (float): temperatur value
+            hint (int): (optional) hint for the selection logic to decide which part of the melting curve to use
+
+        Returns:
+            p (float): preassure or NaN if arguments are out of range
+        """
+        T = self.unitConverter.toSIunit_T(t)
+
+        if hint is None:
+            if T >= 251.165 and T < 256.164:
+                self.logger.error('cant select ice type based on temperatur, hint reqired')
+                return float("NaN")
+            elif T >= 256.164 and T < 273.31:
+                self.logger.debug('chose ice type V based on temperature')
+                return self.unitConverter.fromSIunit_p(R14.pmelt_T_iceV(T))
+            elif T >= 273.31 and T < 355:
+                self.logger.debug('chose ice type VI based on temperature')
+                return self.unitConverter.fromSIunit_p(R14.pmelt_T_iceVI(T))
+            elif T >= 355 and T < 751:
+                self.logger.debug('chose ice type VII based on temperature')
+                return self.unitConverter.fromSIunit_p(R14.pmelt_T_iceVII(T))
+            else:
+                self.logger.warning('temperature out of range')
+                return float("NaN")
+
+        elif hint is self.TYPE_ICE_Ih:
+            if T >= 251.165 and T < 273.16:
+                return self.unitConverter.fromSIunit_p(IAPWS_R14.pmelt_T_iceIh(T))
+            else:
+                self.logger.warning('pressure out of range')
+                return float("NaN")
+
+        elif hint is self.TYPE_ICE_III:
+            if T >= 251.165 and T < 256.164:
+                return self.unitConverter.fromSIunit_p(IAPWS_R14.pmelt_T_iceIII(T))
+            else:
+                self.logger.warning('pressure out of range')
+                return float("NaN")
+
+        elif hint is self.TYPE_ICE_V:
+            if T >= 256.164 and T < 273.31:
+                return self.unitConverter.fromSIunit_p(IAPWS_R14.pmelt_T_iceV(T))
+            else:
+                self.logger.warning('pressure out of range')
+                return float("NaN")
+
+        elif hint is self.TYPE_ICE_VI:
+            if T >= 273.31 and T < 355:
+                return self.unitConverter.fromSIunit_p(IAPWS_R14.pmelt_T_iceVI(T))
+            else:
+                self.logger.warning('pressure out of range')
+                return float("NaN")
+
+        elif hint is self.TYPE_ICE_VII:
+            if T >= 355 and T < 751:
+                return self.unitConverter.fromSIunit_p(IAPWS_R14.pmelt_T_iceVII(T))
+            else:
+                self.logger.warning('pressure out of range')
+                return float("NaN")
+
+        else:
+            self.logger.error('unknown hint, cant select ice type')
+            raise ValueError('unknown hint')
+
+    def psubl_t(self, t):
+        """Pressure along the sublimation curve as a function of temperature. Based on IAPWS R14-08(2011)
+        http://www.iapws.org/relguide/MeltSub2011.pdf
+
+        Args:
+            t (float): temperatur value
+
+        Returns:
+            p (float): preassure or NaN if arguments are out of range
+        """
+        T = self.unitConverter.toSIunit_T(t)
+        if T >= 50 and T < 273.16:
+            return self.unitConverter.fromSIunit_p(IAPWS_R14.psubl_T(T))
+        else:
+            self.logger.warning('temperature out of range')
+            return float("NaN")
